<?php
namespace XLite\Module\CDev\Coupons\View;
/**
 * Cart coupons
 *
 * @ListChild (list="cart.panel.box", weight="200")
 * @ListChild (list="checkout.review.selected", weight="15")
 * @ListChild (list="checkout_fastlane.sections.details", weight="200")
 */
class CartCoupons extends \XLite\Module\Amazon\PayWithAmazon\Module\CDev\Coupons\View\CartCoupons {}